@@ -185,7 +185,9 @@ def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, prot
                 sys.__excepthook__(exc_type, exc_value, exc_traceback)
                 return
 
-            logger.critical('Uncaught Exception', data={'traceback': f'{exc_type.__name__}: {exc_value}\n{"".join(traceback.format_tb(exc_traceback))}'})
+            logger.critical('Uncaught Exception', data={'traceback': '{exc_type}: {exc_value}\n{traceback}'.format(exc_type=exc_type.__name__,
+                                                                                                                   exc_value=exc_value,
+                                                                                                                   traceback=''.join(traceback.format_tb(exc_traceback)))})
             sys.__excepthook__(exc_type, exc_value, exc_traceback)
 
         sys.excepthook = watchtower_handle_exception
